@@ -5,6 +5,7 @@ from __future__ import absolute_import
 from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
 from bitmovin_api_sdk.common.poscheck import poscheck_except
 from bitmovin_api_sdk.analytics.outputs.s3_role_based.s3_role_based_api import S3RoleBasedApi
+from bitmovin_api_sdk.analytics.outputs.gcs_service_account.gcs_service_account_api import GcsServiceAccountApi
 
 
 class OutputsApi(BaseApi):
@@ -25,3 +26,10 @@ class OutputsApi(BaseApi):
             base_url=base_url,
             logger=logger
         )
+
+        self.gcs_service_account = GcsServiceAccountApi(
+            api_key=api_key,
+            tenant_org_id=tenant_org_id,
+            base_url=base_url,
+            logger=logger
+        )
