@@ -341,6 +341,7 @@ from bitmovin_api_sdk.models.id3_tag_position_mode import Id3TagPositionMode
 from bitmovin_api_sdk.models.id3_tag_type import Id3TagType
 from bitmovin_api_sdk.models.ignored_by import IgnoredBy
 from bitmovin_api_sdk.models.ignoring import Ignoring
+from bitmovin_api_sdk.models.image_adaptation_set import ImageAdaptationSet
 from bitmovin_api_sdk.models.infrastructure_settings import InfrastructureSettings
 from bitmovin_api_sdk.models.ingest_input_stream import IngestInputStream
 from bitmovin_api_sdk.models.input import Input
@@ -449,6 +450,7 @@ from bitmovin_api_sdk.models.period import Period
 from bitmovin_api_sdk.models.permission import Permission
 from bitmovin_api_sdk.models.picture_field_parity import PictureFieldParity
 from bitmovin_api_sdk.models.pixel_format import PixelFormat
+from bitmovin_api_sdk.models.pixel_format_bit_depth import PixelFormatBitDepth
 from bitmovin_api_sdk.models.plaintext_id3_tag import PlaintextId3Tag
 from bitmovin_api_sdk.models.play_ready_additional_information import PlayReadyAdditionalInformation
 from bitmovin_api_sdk.models.play_ready_drm import PlayReadyDrm
@@ -534,6 +536,9 @@ from bitmovin_api_sdk.models.source_channel_type import SourceChannelType
 from bitmovin_api_sdk.models.speke_drm import SpekeDrm
 from bitmovin_api_sdk.models.speke_drm_provider import SpekeDrmProvider
 from bitmovin_api_sdk.models.sprite import Sprite
+from bitmovin_api_sdk.models.sprite_creation_mode import SpriteCreationMode
+from bitmovin_api_sdk.models.sprite_jpeg_config import SpriteJpegConfig
+from bitmovin_api_sdk.models.sprite_representation import SpriteRepresentation
 from bitmovin_api_sdk.models.sprite_unit import SpriteUnit
 from bitmovin_api_sdk.models.srt_input import SrtInput
 from bitmovin_api_sdk.models.srt_mode import SrtMode
@@ -628,6 +633,8 @@ from bitmovin_api_sdk.models.web_vtt_configuration import WebVttConfiguration
 from bitmovin_api_sdk.models.web_vtt_cue_identifier_policy import WebVttCueIdentifierPolicy
 from bitmovin_api_sdk.models.web_vtt_sidecar_file import WebVttSidecarFile
 from bitmovin_api_sdk.models.web_vtt_sidecar_file_segmentation import WebVttSidecarFileSegmentation
+from bitmovin_api_sdk.models.web_vtt_styling import WebVttStyling
+from bitmovin_api_sdk.models.web_vtt_styling_mode import WebVttStylingMode
 from bitmovin_api_sdk.models.webhook import Webhook
 from bitmovin_api_sdk.models.webhook_http_method import WebhookHttpMethod
 from bitmovin_api_sdk.models.webhook_notification import WebhookNotification
